var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import invariant from 'invariant';
import { axiosService } from './axios';
import { isFunction, isArray, isObject } from 'friday-helpers';
import { getDisasterRecoveryData } from './useRequest/utils';
const responseSchemaValidate = (response, isBlob) => {
    if (!response) {
        throw Error('[dispatchAsync response error] response undefined');
    }
    // istanbul ignore next
    const data = response === null || response === void 0 ? void 0 : response.data;
    if (!isArray(data) && !isObject(data) && !isBlob) {
        throw Error('[dispatchAsync response error]  data must be array | object');
    }
    return response;
};
export const dispatchAsync = (service) => __awaiter(void 0, void 0, void 0, function* () {
    const axiosInstance = axiosService.getAixosInstance();
    invariant(axiosInstance, '[dispatchAsync] axiosInstance not found');
    invariant((isObject(service) || isFunction(service)), '[dispatchAsync]  service not found, service must be object or function');
    let axiosConfig;
    if (isObject(service)) {
        axiosConfig = service;
    }
    if (isFunction(service)) {
        axiosConfig = service();
    }
    const isBlob = (axiosConfig === null || axiosConfig === void 0 ? void 0 : axiosConfig.responseType) === 'blob';
    return axiosInstance(axiosConfig)
        .then((result) => {
        return responseSchemaValidate(result, isBlob);
    })
        .then((result) => {
        // istanbul ignore next
        const _data = getDisasterRecoveryData(result, isBlob);
        return Object.assign(Object.assign(Object.assign({}, result), _data), { error: null });
    })
        .catch((error) => {
        const _data = getDisasterRecoveryData({}, isBlob);
        return Object.assign({ error }, _data);
    });
});
//# sourceMappingURL=dispatchAsync.js.map