import React from 'react';
import invariant from 'invariant';
import useAsync from './useAsync';
import usePagination from './usePagination';
import useLoadMore from './useLoadMore';
import useManalRequest from './useManalAsync';
function useRequest(service, config = {}) {
    const { paginated, loadMore, manual } = config;
    const paginatedRef = React.useRef(paginated);
    const loadMoreRef = React.useRef(loadMore);
    if (paginatedRef.current !== paginated || loadMoreRef.current !== loadMore) {
        invariant(false, 'You should not modify the paginated or loadMore of options');
    }
    if (paginated && loadMore && manual) {
        invariant(false, 'paginated 、 manual and loadmore  are mutually exclusive, only one can be selected');
    }
    paginatedRef.current = paginated;
    loadMoreRef.current = loadMore;
    if (paginated) {
        return usePagination(service, config);
    }
    if (loadMore) {
        return useLoadMore(service, config);
    }
    // 手动触发， 暂时不支持分页。有需求在扩展
    if (manual) {
        return useManalRequest(service, config);
    }
    return useAsync(service, config);
}
export default useRequest;
//# sourceMappingURL=index.js.map