var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { createGetApi, createPostApi } from '../genarateApi';
import { renderHook, act } from '@testing-library/react-hooks';
import useRequest from './index';
describe('useRequest', () => {
    it('General Get Request', () => __awaiter(void 0, void 0, void 0, function* () {
        const getApi = createGetApi({ url: '/a' });
        const fetcher = (config) => {
            return Object.assign(Object.assign({}, config), { data: { test: 1 } });
        };
        const { result, waitFor } = renderHook(() => useRequest(getApi(), {
            fetcher,
        }));
        yield waitFor(() => expect(result.current.dataJson).toMatchObject({ test: 1 }));
    }));
    it('General post Request', () => __awaiter(void 0, void 0, void 0, function* () {
        const postApi = createPostApi({ url: '/a' });
        const fetcher = (config) => {
            return Object.assign(Object.assign({}, config), { data: { test: 1 } });
        };
        const { result, waitFor } = renderHook(() => useRequest(postApi(), {
            fetcher,
        }));
        yield waitFor(() => expect(result.current.dataJson).toMatchObject({ test: 1 }));
    }));
    it('General paginated Request', () => __awaiter(void 0, void 0, void 0, function* () {
        const getApi = createGetApi({ url: '/a' });
        const fetcher = (config) => {
            return Object.assign(Object.assign({}, config), { data: { test: 1 } });
        };
        const { result, waitFor } = renderHook(() => useRequest(getApi(), {
            fetcher,
            paginated: true
        }));
        yield waitFor(() => {
            expect(result.current.dataJson).toMatchObject({ test: 1 });
            expect(result.current.params).toMatchObject({ page: 1, pageSize: 10 });
            expect(result.current.onLoadMore).toBeTruthy();
        });
    }));
    it('General loadMore Request', () => __awaiter(void 0, void 0, void 0, function* () {
        const getApi = createGetApi({ url: '/abc' });
        const fetcher = (config) => {
            return Object.assign(Object.assign({}, config), { data: [{ test: 1 }] });
        };
        const { result, waitForValueToChange } = renderHook(() => useRequest(getApi(), {
            fetcher,
            loadMore: true
        }));
        yield waitForValueToChange(() => result.current.list);
        expect(result.current.list).toMatchObject([{ test: 1 }]);
        act(() => {
            result.current.onLoadMore();
        });
        yield waitForValueToChange(() => result.current.list);
        expect(result.current.params).toMatchObject({ page: 2, pageSize: 10 });
    }));
    it('General manual Request', () => __awaiter(void 0, void 0, void 0, function* () {
        const getApi = createGetApi({ url: '/abc' });
        const mockCallback = jest.fn();
        const fetcher = (config) => {
            return Object.assign(Object.assign({}, config), { data: [{ test: 1 }] });
        };
        const { result, waitFor } = renderHook(() => useRequest(getApi, {
            fetcher,
            manual: true,
            onSuccess: () => {
                mockCallback();
            }
        }));
        yield waitFor(() => {
            expect(result.current.dataArray).toMatchObject([]);
        });
        // 触发
        act(() => result.current.run());
        yield waitFor(() => {
            expect(mockCallback.mock.calls.length).toBe(1);
        });
    }));
});
//# sourceMappingURL=index.test.js.map