import React from 'react';
import invariant from 'invariant';
import useSWR from 'swr';
import { AsyncConfigContext } from './context';
import { getParams, fetcherWarpper, genarateServiceConfig, getDisasterRecoveryData, } from './utils';
const DEFAULT_CONFIG = {
    shouldRetryOnError: false,
    revalidateOnFocus: false
};
function useAsync(service, config) {
    const serviceConfig = genarateServiceConfig(service);
    const serviceRef = React.useRef(serviceConfig);
    serviceRef.current = serviceConfig;
    const globalConfig = React.useContext(AsyncConfigContext);
    const requestConfig = Object.assign({}, DEFAULT_CONFIG, globalConfig, config || {});
    invariant(requestConfig.fetcher, '[fetcher] fetcher is a required configuration item, can be passed in through request_middleware or AsyncRequestProvider');
    const overRewriteConfig = Object.assign(Object.assign({}, requestConfig), { fetcher: fetcherWarpper(requestConfig.fetcher), onSuccess: (data, key, config) => {
            if (requestConfig === null || requestConfig === void 0 ? void 0 : requestConfig.onSuccess) {
                const disasterRecoveryData = getDisasterRecoveryData(data);
                requestConfig.onSuccess(Object.assign({ key,
                    data,
                    config, params: getParams(serviceRef.current) }, disasterRecoveryData));
            }
        } });
    const configRef = React.useRef(overRewriteConfig);
    configRef.current = overRewriteConfig;
    const serializeKey = React.useMemo(() => {
        if (!serviceRef.current)
            return null;
        try {
            return JSON.stringify(serviceRef.current);
        }
        catch (error) {
            return new Error(error);
        }
    }, [
        serviceRef.current,
        configRef.current.isPaused
    ]);
    if (serializeKey instanceof Error) {
        invariant(false, '[serializeKey] service must be object');
    }
    const response = useSWR(serializeKey, configRef.current);
    const disasterRecoveryData = React.useMemo(() => {
        return getDisasterRecoveryData(response === null || response === void 0 ? void 0 : response.data);
    }, [response.data]);
    return Object.assign(Object.assign(Object.assign({}, response), disasterRecoveryData), { params: getParams(serviceRef.current) });
}
export default useAsync;
//# sourceMappingURL=useAsync.js.map