import warning from 'warning';
import invariant from 'invariant';
import { isArray, isObject, isEqual, isFunction } from 'friday-helpers';
export const genarateServiceConfig = (service) => {
    if (isObject(service)) {
        return service;
    }
    if (isFunction(service)) {
        return service();
    }
    return null;
};
export const contrastServiceParams = (preService, curService) => {
    const preServiceParams = getServiceParams(preService);
    const curServiceParams = getServiceParams(curService);
    return isEqual(preServiceParams, curServiceParams);
};
export const getServiceParams = (service) => {
    const serviceResult = genarateServiceConfig(service);
    if (serviceResult == null)
        throw 'service is null';
    const paramsKey = serviceResult.method == 'get' ? 'params' : 'data';
    return serviceResult[paramsKey];
};
export const mergeServiceParams = (preServiceConfig, mergeParams) => {
    if (!mergeParams)
        return preServiceConfig;
    if (!preServiceConfig || !preServiceConfig.method) {
        invariant(false, 'service 不合法');
    }
    const method = preServiceConfig.method;
    const payloadKey = method == 'get' ? 'params' : 'data';
    return Object.assign(Object.assign({}, preServiceConfig), { [payloadKey]: Object.assign(Object.assign({}, preServiceConfig[payloadKey]), mergeParams) });
};
const validator = (axiosResponse, rule, defaultVal) => {
    if (Object.prototype.toString.call(axiosResponse === null || axiosResponse === void 0 ? void 0 : axiosResponse.data) !== `[object ${rule}]`) {
        return { data: defaultVal };
    }
    // istanbul ignore next
    return axiosResponse;
};
export const getDisasterRecoveryData = (axiosResponse, isBlob = false) => {
    if (axiosResponse !== undefined &&
        /* istanbul ignore next */
        (!isArray(axiosResponse === null || axiosResponse === void 0 ? void 0 : axiosResponse.data) && !isObject(axiosResponse === null || axiosResponse === void 0 ? void 0 : axiosResponse.data)) &&
        !isBlob) {
        warning(false, '接口返回格式错误, data没返回，或者不是array | object');
    }
    const responseJson = validator(axiosResponse, 'Object', {});
    const responseArray = validator(axiosResponse, 'Array', []);
    return {
        responseBlob: isBlob ? axiosResponse : null,
        responseArray,
        responseJson,
        dataArray: responseArray.data,
        dataJson: responseJson.data,
    };
};
export const fetcherWarpper = (fetcher) => {
    if (!fetcher)
        return undefined;
    return (axiosConfigString) => {
        let axiosConfig;
        try {
            axiosConfig = JSON.parse(axiosConfigString);
        }
        catch (error) {
            axiosConfig = new Error(error);
        }
        if (axiosConfig instanceof Error) {
            invariant(false, '[fetcher parse] axiosConfig parse error');
        }
        return fetcher(axiosConfig);
    };
};
export const getParams = (objectService) => {
    if (!objectService)
        return undefined;
    return ((objectService === null || objectService === void 0 ? void 0 : objectService.params) || (objectService === null || objectService === void 0 ? void 0 : objectService.data) ||
        {});
};
//# sourceMappingURL=utils.js.map